package cofh.thermal.expansion.block.entity.machine;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import cofh.core.util.helpers.FluidHelper;
import cofh.lib.api.StorageGroup;
import cofh.lib.fluid.FluidStorageCoFH;
import cofh.lib.inventory.ItemStorageCoFH;
import cofh.thermal.core.config.ThermalCoreConfig;
import cofh.thermal.core.util.managers.machine.BrewerRecipeManager;
import cofh.thermal.expansion.init.TExpTileEntities;
import cofh.thermal.expansion.inventory.container.machine.MachineBrewerContainer;
import cofh.thermal.lib.block.entity.MachineBlockEntity;
import cofh.thermal.lib.util.recipes.IMachineInventory;
import cofh.thermal.lib.util.recipes.IThermalInventory;
import javax.annotation.Nullable;
import net.minecraft.core.BlockPos;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.inventory.AbstractContainerMenu;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.level.material.Fluid;
import net.minecraft.world.level.material.Fluids;
import net.minecraftforge.fluids.FluidStack;

public class MachineBrewerTile extends MachineBlockEntity {
  protected ItemStorageCoFH inputSlot;
  
  protected FluidStorageCoFH inputTank;
  
  protected FluidStorageCoFH outputTank;
  
  public MachineBrewerTile(BlockPos pos, BlockState state) {
    super((BlockEntityType)TExpTileEntities.MACHINE_BREWER_TILE.get(), pos, state);
    this.inputSlot = new ItemStorageCoFH(item -> (this.filter.valid(item) && BrewerRecipeManager.instance().validItem(item)));
    this.inputTank = new FluidStorageCoFH(4000, fluid -> (this.filter.valid(fluid) && BrewerRecipeManager.instance().validFluid(fluid)));
    this.outputTank = new FluidStorageCoFH(8000);
    this.inventory.addSlot(this.inputSlot, StorageGroup.INPUT);
    this.inventory.addSlot(this.chargeSlot, StorageGroup.INTERNAL);
    this.tankInv.addTank(this.inputTank, StorageGroup.INPUT);
    this.tankInv.addTank(this.outputTank, StorageGroup.OUTPUT);
    this.renderFluid = new FluidStack((Fluid)Fluids.f_76193_, 1000);
    addAugmentSlots(ThermalCoreConfig.machineAugments);
    initHandlers();
  }
  
  protected int getBaseProcessTick() {
    return BrewerRecipeManager.instance().getBasePower();
  }
  
  protected boolean cacheRecipe() {
    this.curRecipe = BrewerRecipeManager.instance().getRecipe((IThermalInventory)this);
    if (this.curRecipe != null) {
      this.itemInputCounts = this.curRecipe.getInputItemCounts((IMachineInventory)this);
      this.fluidInputCounts = this.curRecipe.getInputFluidCounts((IMachineInventory)this);
    } 
    return (this.curRecipe != null);
  }
  
  protected boolean cacheRenderFluid() {
    if (this.curRecipe == null)
      return false; 
    FluidStack prevFluid = this.renderFluid;
    this.renderFluid = new FluidStack(this.curRecipe.getOutputFluids((IMachineInventory)this).get(0), 1000);
    return !FluidHelper.fluidsEqual(this.renderFluid, prevFluid);
  }
  
  @Nullable
  public AbstractContainerMenu m_7208_(int i, Inventory inventory, Player player) {
    return (AbstractContainerMenu)new MachineBrewerContainer(i, this.f_58857_, this.f_58858_, inventory, player);
  }
  
  protected boolean validateInputs() {
    if (!cacheRecipe())
      return false; 
    return (this.inputSlot.getCount() >= ((Integer)this.itemInputCounts.get(0)).intValue() && this.inputTank.getAmount() >= ((Integer)this.fluidInputCounts.get(0)).intValue());
  }
  
  protected boolean validateOutputs() {
    if (this.curRecipe == null && !cacheRecipe())
      return false; 
    if (this.outputTank.isEmpty())
      return true; 
    FluidStack output = this.outputTank.getFluidStack();
    FluidStack recipeOutput = this.curRecipe.getOutputFluids((IMachineInventory)this).get(0);
    if (this.outputTank.getSpace() < recipeOutput.getAmount())
      return false; 
    return FluidHelper.fluidsEqual(output, recipeOutput);
  }
}
